AvroRead

Trait AvroRead 

pub trait AvroRead: Read + Skip { }
A convenience trait for types that are both readable and skippable.

A blanket implementation is provided for all types that implement both Read and Skip.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> AvroRead for T
where T: Read + Skip,